==> jc-1.4.0.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24ZipMatcher.h <==
// class org.dellroad.jc.BootstrapObjectGenerator$ZipMatcher

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher
// @dep_class 64d406de50a0ea41 org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher

// header file dependencies
// @dep_header org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

#include "org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_zip_ZipFile$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$_init$538ee07130435a5e(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_io_File$object *);

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *);
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_lang_String$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method_info$getMatches$65d62d43654fc8a6;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *);
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_lang_String$object *, jint);
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs {
	struct _jc_java_util_zip_ZipFile$object	*zfile;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_ */

==> jc-1.4.6.tar.gz: org/dellroad/jc/BootstrapObjectGenerator__24ZipMatcher.h <==
// class org.dellroad.jc.BootstrapObjectGenerator$ZipMatcher

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 25215c5cc24f2d81 org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher
// @dep_class 64d406de50a0ea41 org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher

// header file dependencies
// @dep_header org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher

#include "org/dellroad/jc/BootstrapObjectGenerator__24SearchpathMatcher.h"

#ifndef _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_
#define _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Set$object;
struct _jc_java_util_zip_ZipFile$object;

// Typedefs
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs;
typedef struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object;

typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable;
typedef const struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype;

// Constructors
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$_init$538ee07130435a5e(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$finalize$660a5b5b608ff21f(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method$getMatches$65d62d43654fc8a6(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method_info$finalize$660a5b5b608ff21f;
extern _jc_method _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$method_info$getMatches$65d62d43654fc8a6;

// Virtual methods structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods {
	void	(*finalize$660a5b5b608ff21f)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getMatches$65d62d43654fc8a6)(_jc_env *, struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vmethods	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
};

// Vtype
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype {
	_jc_type			type;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs {
	struct _jc_java_util_zip_ZipFile$object	*zfile;
};

// Reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs {
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_refs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24SearchpathMatcher;
    _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$sub_nonrefs	org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher;
};

// Object instance structure
struct _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$object {
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$refs	refs[0];
	_jc_word		lockword;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype	*vtype;
	_jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$vtype _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher$class_object;

#endif	/* _JC_org_dellroad_jc_BootstrapObjectGenerator__24ZipMatcher_H_ */
